# Environmental Biophysics
[![CI](https://github.com/gcamargo1/environmental-biophysics/actions/workflows/push_workflow.yml/badge.svg)](https://github.com/gcamargo1/environmental-biophysics/actions/workflows/push_workflow.yml)
[![PyPI version](https://badge.fury.io/py/environmental-biophysics.svg)](https://badge.fury.io/py/environmental-biophysics)

[//]: # ([![codecov]&#40;https://codecov.io/gh/dunossauro/notas-musicais/branch/main/graph/badge.svg?token=OVQQF4IQY2&#41;]&#40;https://codecov.io/gh/dunossauro/notas-musicais&#41;)
[//]: # ([![Documentation Status]&#40;https://readthedocs.org/projects/notas-musicais/badge/?version=latest&#41;]&#40;https://notas-musicais.readthedocs.io/en/latest/?badge=latest&#41;)

Environmental biophysics package for modeling.

Documentation at: https://gcamargo1.github.io/environmental-biophysics/
